@@ -1,7 +1,5 @@
 /* 
-   ipmi-chassis-argp.h - IPMI Chassis
-   
-   Copyright (C) 2007 FreeIPMI Core Team
+   Copyright (C) 2007-2008 FreeIPMI Core Team
    
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -23,6 +21,4 @@
 
 void ipmi_chassis_argp_parse (int argc, char **argv, struct ipmi_chassis_arguments *cmd_args);
 
-int ipmi_chassis_args_validate (struct ipmi_chassis_arguments *args);
-
 #endif
