@@ -1,7 +1,7 @@
 /*****************************************************************************\
- *  $Id: ipmipower_util.c,v 1.18 2007/10/18 16:18:53 chu11 Exp $
+ *  $Id: ipmipower_util.c,v 1.25 2008/08/12 18:14:41 chu11 Exp $
  *****************************************************************************
- *  Copyright (C) 2007 Lawrence Livermore National Security, LLC.
+ *  Copyright (C) 2007-2008 Lawrence Livermore National Security, LLC.
  *  Copyright (C) 2003-2007 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
  *  Written by Albert Chu <chu11@llnl.gov>
@@ -37,8 +37,9 @@
 #include <assert.h>
 
 #include "ipmipower_util.h"
+#include "ierror.h"
 
-#include "error.h"
+#include "freeipmi-portability.h"
 
 uint32_t
 get_rand(void)
@@ -47,7 +48,7 @@ get_rand(void)
 
   if (ipmi_get_random((uint8_t *)&val, sizeof(val)) < 0)
     {
-      err_output("get_rand: ipmi_get_random: %s", strerror(errno));
+      ierr_dbg("get_rand: ipmi_get_random: %s", strerror(errno));
       return (uint32_t)rand();
     }
 
