@@ -403,6 +403,51 @@ ipmi_cmd_get_bt_interface_capabilities (ipmi_ctx_t ctx,
   return (rv);
 }
 
+int8_t
+ipmi_cmd_master_write_read (ipmi_ctx_t ctx,
+                            uint8_t bus_type,
+                            uint8_t bus_id,
+                            uint8_t channel_number,
+                            uint8_t slave_address,
+                            uint8_t read_count,
+                            const void *data,
+                            unsigned int data_len,
+                            fiid_obj_t obj_cmd_rs)
+{
+  fiid_obj_t obj_cmd_rq = NULL;
+  int rv = -1;
+  
+  API_ERR_CTX_CHECK (ctx && ctx->magic == IPMI_CTX_MAGIC);
+  
+  /* note, don't check channel number, since this is a master write-read command */
+  API_ERR_PARAMETERS (IPMI_BUS_TYPE_VALID (bus_type)
+                      && fiid_obj_valid(obj_cmd_rs));
+  
+  API_FIID_OBJ_TEMPLATE_COMPARE (obj_cmd_rs,
+                                 tmpl_cmd_master_write_read_rs);
+  
+  API_FIID_OBJ_CREATE (obj_cmd_rq, tmpl_cmd_master_write_read_rq);
+  
+  API_ERR_CLEANUP (!(fill_cmd_master_write_read (bus_type,
+                                                 bus_id,
+                                                 channel_number,
+                                                 slave_address,
+                                                 read_count,
+                                                 data,
+                                                 data_len,
+                                                 obj_cmd_rq) < 0));
+  
+  API_ERR_IPMI_CMD_CLEANUP (ctx, 
+                            IPMI_BMC_IPMB_LUN_BMC, 
+                            IPMI_NET_FN_APP_RQ, 
+                            obj_cmd_rq,
+                            obj_cmd_rs);
+  
+  rv = 0;
+ cleanup:
+  API_FIID_OBJ_DESTROY(obj_cmd_rq);
+  return (rv);
+}
 
 int8_t 
 ipmi_cmd_get_channel_authentication_capabilities (ipmi_ctx_t ctx, 
